@@ -1,5 +1,4 @@
-use crate::type_information;
-
+#[pen_ffi_macro::any_conv(crate = "crate")]
 #[repr(C)]
 #[derive(Clone, Copy, Debug, Default, Eq, PartialEq)]
 pub struct Boolean {
@@ -23,5 +22,3 @@ impl From<bool> for Boolean {
         Self::new(value)
     }
 }
-
-type_information!(boolean, crate::boolean::Boolean);
